--
-- Copyright 2024 The Android Open Source Project
--
-- Licensed under the Apache License, Version 2.0 (the "License");
-- you may not use this file except in compliance with the License.
-- You may obtain a copy of the License at
--
--     https://www.apache.org/licenses/LICENSE-2.0
--
-- Unless required by applicable law or agreed to in writing, software
-- distributed under the License is distributed on an "AS IS" BASIS,
-- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-- See the License for the specific language governing permissions and
-- limitations under the License.

-- Returns whether a machine is running a Linux kernel.
CREATE PERFETTO FUNCTION _is_linux_machine(
    -- Machine id.
    machine_id JOINID(machine.id)
)
RETURNS LONG AS
SELECT
  count() = 1
FROM metadata
WHERE
  name = 'system_name' AND str_value = 'Linux' AND machine_id = $machine_id;
